<?xml version="1.0" ?><!DOCTYPE TS><TS language="is" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;h2&gt;%1 Client %2&lt;/h2&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;h5&gt; REV %1 &lt;/h5&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>About</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Check For Updates</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AccountManager</name>
    <message>
        <source>failed to open account database</source>
        <translation>mistókst að opna gagnagrunn reiknings</translation>
    </message>
    <message>
        <source>Authorization expired, please re-login</source>
        <translation>Aðgangur útrunninn, vinsamlegast skráðu þig inn aftur</translation>
    </message>
</context>
<context>
    <name>AccountSettingsDialog</name>
    <message>
        <source>Account Settings</source>
        <translation>Persónulegar stillingar</translation>
    </message>
    <message>
        <source>Please enter the server address</source>
        <translation>Vinsamlegast setjið inn veffang þjóns</translation>
    </message>
    <message>
        <source>%1 is not a valid server address</source>
        <translation>%1 er ekki rétt veffang þjóns</translation>
    </message>
    <message>
        <source>Failed to save account information</source>
        <translation>Mistókst að vista reikningsupplýsingar</translation>
    </message>
    <message>
        <source>Failed to save the changes: %1</source>
        <translation>Mistókst að vista breytingarnar: %1</translation>
    </message>
    <message>
        <source>Successfully updated current account information</source>
        <translation>Tókst með ágætum að uppfæra reikningsupplýsingar</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Svargluggi</translation>
    </message>
    <message>
        <source>Server Address</source>
        <translation>Veffang Þjóns</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Netfang</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Í lagi</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Hætta við</translation>
    </message>
</context>
<context>
    <name>AccountView</name>
    <message>
        <source>Are you sure you want to remove account %1?&lt;br&gt;&lt;br&gt;The account will be removed locally. All syncing configuration will be removed too. The account at the server will not be affected.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to unsync libraries of this account: %1</source>
        <translation>Mistókst að taka samstilla af fyrir þennan reikning: %1</translation>
    </message>
    <message>
        <source>click to open the website</source>
        <translation>smelltu til að opna vefsíðuna</translation>
    </message>
    <message>
        <source>pro version</source>
        <translation>Sér útgáfa</translation>
    </message>
    <message>
        <source>No account</source>
        <translation>Enginn reikningur</translation>
    </message>
    <message>
        <source>Choose</source>
        <translation>Veldu</translation>
    </message>
    <message>
        <source>Account settings</source>
        <translation>Stillingar reiknings</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Innskrá</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eyða</translation>
    </message>
    <message>
        <source>Add an account</source>
        <translation>Bæta við reikningi</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Útskrá</translation>
    </message>
    <message>
        <source>not logged in</source>
        <translation>ekki skráður inn</translation>
    </message>
    <message>
        <source>Failed to remove local repos sync token: %1</source>
        <translation>Mistókst að fjarlægja staðvært samstillingartákn: %1</translation>
    </message>
    <message>
        <source>Failed to get repo sync information from server: %1</source>
        <translation>Mistókst að sækja samstillingarupplýsingar safns frá þjóni: %1</translation>
    </message>
    <message>
        <source>Form</source>
        <translation>Form</translation>
    </message>
    <message>
        <source>Account</source>
        <translation>Reikningur</translation>
    </message>
    <message>
        <source>email</source>
        <translation>netfang</translation>
    </message>
    <message>
        <source>server</source>
        <translation>þjónn</translation>
    </message>
</context>
<context>
    <name>ActivitiesTab</name>
    <message>
        <source>File Activities are only supported in %1 Server Professional Edition.</source>
        <translation>Virkni er aðeins studd í %1 Server Professional Edition.</translation>
    </message>
    <message>
        <source>retry</source>
        <translation>reyna aftur</translation>
    </message>
    <message>
        <source>Failed to get actvities information. Please %1</source>
        <translation>Mistókst að sækja upplýsingar um hreyfingar. Vinsamlegast %1</translation>
    </message>
</context>
<context>
    <name>AutoUpdateManager</name>
    <message>
        <source>Upload Success</source>
        <translation>Upphleðsla Tókst</translation>
    </message>
    <message>
        <source>File &quot;%1&quot;
uploaded successfully.</source>
        <translation>Skrá &quot;%1&quot;
hlaðið upp giftursamlega.</translation>
    </message>
    <message>
        <source>File &quot;%1&quot;
failed to upload.</source>
        <translation>Skrá &quot;%1&quot;
mistókst að hlaða upp.</translation>
    </message>
    <message>
        <source>Permission Error!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Authorization expired</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File does not exist</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The file is locked by %1, please try again later</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Upload Failure: %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AvatarService</name>
    <message>
        <source>Failed to create avatars folder</source>
        <translation>Mistókst að búa til skráarsafn fyrir smámyndir</translation>
    </message>
</context>
<context>
    <name>CheckRepoRootDirPermDialog</name>
    <message>
        <source>Checking Permission</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CloneTasksDialog</name>
    <message>
        <source>Download tasks</source>
        <translation>Niðurhalsverk</translation>
    </message>
    <message>
        <source>remove all successful tasks</source>
        <translation>fjarlægja öll verk sem eru kláruð</translation>
    </message>
    <message>
        <source>No download tasks right now.</source>
        <translation>Engin niðurhalsverk akkúrat núna.</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Svargluggi</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Hreinsa</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Loka</translation>
    </message>
</context>
<context>
    <name>CloneTasksTableModel</name>
    <message>
        <source>Library</source>
        <translation>Safn</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Slóð</translation>
    </message>
</context>
<context>
    <name>CloneTasksTableView</name>
    <message>
        <source>Cancel this task</source>
        <translation>Hætta við þetta verk</translation>
    </message>
    <message>
        <source>cancel this task</source>
        <translation>hætta þessu verki</translation>
    </message>
    <message>
        <source>Remove this task</source>
        <translation>Fjarlægja þetta verk</translation>
    </message>
    <message>
        <source>Failed to cancel this task:

 %1</source>
        <translation>Mistókst að hætta við þetta verk:

 %1</translation>
    </message>
    <message>
        <source>Failed to remove this task:

 %1</source>
        <translation>Mistókst að fjarlægja þetta verk:

 %1</translation>
    </message>
</context>
<context>
    <name>CloudView</name>
    <message>
        <source>Minimize</source>
        <translation>Minnka</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Loka</translation>
    </message>
    <message>
        <source>Libraries</source>
        <translation>Söfn</translation>
    </message>
    <message>
        <source>Starred</source>
        <translation>Stjörnumerkt</translation>
    </message>
    <message>
        <source>Activities</source>
        <translation>Hreyfingar</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Leita</translation>
    </message>
    <message>
        <source>current download rate</source>
        <translation>núverandi niðurhalshraði</translation>
    </message>
    <message>
        <source>current upload rate</source>
        <translation>núverandi upphleðsluhraði</translation>
    </message>
    <message>
        <source>Please Choose a folder to sync</source>
        <translation>Vinsamlegast veldu skáarsafn til að samkeyra</translation>
    </message>
    <message>
        <source>no server connected</source>
        <translation>enginn þjónn tengdur</translation>
    </message>
    <message>
        <source>all servers connected</source>
        <translation>allir þjónar tengdir</translation>
    </message>
    <message>
        <source>some servers not connected</source>
        <translation>sumir þjónar ekki tengdir</translation>
    </message>
    <message>
        <source>Form</source>
        <translation>Form</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>logo</translation>
    </message>
    <message>
        <source>minimize</source>
        <translation>minnka</translation>
    </message>
    <message>
        <source>close</source>
        <translation>loka</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Veldu</translation>
    </message>
    <message>
        <source>brand</source>
        <translation>brand</translation>
    </message>
    <message>
        <source>or Drop Folder to Sync</source>
        <translation>eða Dragðu og Slepptu skráarsafni hingað</translation>
    </message>
    <message>
        <source>download rate</source>
        <translation>niðurhalshraði</translation>
    </message>
    <message>
        <source>downarrow</source>
        <translation>ör niður</translation>
    </message>
    <message>
        <source>upload rate</source>
        <translation>upphleðsluhraði</translation>
    </message>
    <message>
        <source>uparrow</source>
        <translation>ör upp</translation>
    </message>
</context>
<context>
    <name>Configurator</name>
    <message>
        <source>Error when creating ccnet configuration</source>
        <translation>Villa þegar verið var að búa til styllingar fyrir ccnet</translation>
    </message>
    <message>
        <source>Unable to create preconfigure directory &quot;%1&quot;</source>
        <translation>Get ekki búið til frumstillt möppu &quot;%1&quot;</translation>
    </message>
    <message>
        <source>failed to read %1</source>
        <translation>tókst ekki að lesa %1</translation>
    </message>
</context>
<context>
    <name>CreateRepoDialog</name>
    <message>
        <source>Create a library</source>
        <translation>Búa til safn</translation>
    </message>
    <message>
        <source>Please choose a directory</source>
        <translation>Vinsamlegast veldu skráarsafn</translation>
    </message>
    <message>
        <source>Creating...</source>
        <translation>Er að búa til...</translation>
    </message>
    <message>
        <source>Failed to generate encryption key for this library</source>
        <translation>Mistókst að útbúa dulkóðunarlykil fyrir þetta safn</translation>
    </message>
    <message>
        <source>Please choose the directory to sync</source>
        <translation>Vinsamlegast veldu skráarsafn til að samstilla</translation>
    </message>
    <message>
        <source>The folder %1 does not exist</source>
        <translation>Skráarsafnið %1 er ekki til</translation>
    </message>
    <message>
        <source>Please enter the name</source>
        <translation>Vinsamlegast sláðu inn nafn</translation>
    </message>
    <message>
        <source>Please enter the password</source>
        <translation>Vinsamlegast sláðu inn lykilorðið</translation>
    </message>
    <message>
        <source>Passwords don&apos;t match</source>
        <translation>Lykilorðin stemma ekki</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Óþekkt villa</translation>
    </message>
    <message>
        <source>Failed to add download task:
 %1</source>
        <translation>Tókst ekki að bæta við niðurhalsverki:
 %1</translation>
    </message>
    <message>
        <source>Failed to create library on the server:
%1</source>
        <translation>Mistókst að búa til safn á þjóni:
%1</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Svargluggi</translation>
    </message>
    <message>
        <source>Path:</source>
        <translation>Slóð:</translation>
    </message>
    <message>
        <source>Choose</source>
        <translation>Veldu</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nafn:</translation>
    </message>
    <message>
        <source>encrypted</source>
        <translation>dulkóðað</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Lykilorð:</translation>
    </message>
    <message>
        <source>Password Again:</source>
        <translation>Endurtaktu Lykilorðið:</translation>
    </message>
    <message>
        <source>status text</source>
        <translation>stöðutexti</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Í lagi</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Hætta við</translation>
    </message>
</context>
<context>
    <name>DaemonManager</name>
    <message>
        <source>failed to load ccnet config dir %1</source>
        <translation>tókst ekki að sækja ccnet stillingarskráarsafn %1</translation>
    </message>
    <message>
        <source>%1 client failed to initialize</source>
        <translation>%1 biðlara mistókst að frumstilla</translation>
    </message>
</context>
<context>
    <name>DownloadRepoDialog</name>
    <message>
        <source>Please enter the password</source>
        <translation>Vinsamlegast sláðu inn lykilorðið</translation>
    </message>
    <message>
        <source>Sync library &quot;%1&quot;</source>
        <translation>Samstilla safn &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Sync folder &quot;%1&quot;</source>
        <translation>Samstilla möppu &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Sync to folder:</source>
        <translation>Samkeyra við möppu:</translation>
    </message>
    <message>
        <source>or</source>
        <translation>eða</translation>
    </message>
    <message>
        <source>sync with an existing folder</source>
        <translation>samkeira með möppu ser er nú þegar til</translation>
    </message>
    <message>
        <source>create a new sync folder</source>
        <translation>búa til nýja samkeyrslumöppu</translation>
    </message>
    <message>
        <source>Sync with this existing folder:</source>
        <translation>Samkeyra með þessari möppu:</translation>
    </message>
    <message>
        <source>Please choose a folder</source>
        <translation>Vinsamlegast veldu möppu</translation>
    </message>
    <message>
        <source>The folder does not exist</source>
        <translation>Þessi mappa er ekki til</translation>
    </message>
    <message>
        <source>Please choose the folder to sync.</source>
        <translation>Vinsamlegast veldu möppu til að samkeyra</translation>
    </message>
    <message>
        <source>Your organization disables putting a library outside %1 folder.</source>
        <translation>Samfélagið sem þú tilheyrir hefur afvirkjað möguleikann að setja safn útfyrir %1 möppuna.</translation>
    </message>
    <message>
        <source>Conflicting with existing file &quot;%1&quot;, please choose a different folder.</source>
        <translation>Rekst á við skránna &quot;%1&quot; sem er nú þegar til, vinsamlegast veldu aðra möppu.</translation>
    </message>
    <message>
        <source>Conflicting with existing library &quot;%1&quot;, please choose a different folder.</source>
        <translation>Rekst á við möppuna &quot;%1&quot; sem er nú þegar til, vinsamlegast veldu aðra</translation>
    </message>
    <message>
        <source>The folder &quot;%1&quot; already exists. Are you sure to sync with it (contents will be merged)?</source>
        <translation>Mappan &quot;%1&quot; er þegar til. Ertu viss um að þú viljir samkeyra við hana (efni hennar verður skeytt inn)?</translation>
    </message>
    <message>
        <source>Click No to sync with a new folder instead</source>
        <translation>Veldu Nei til að samkeyra frekar við nýja möppu</translation>
    </message>
    <message>
        <source>Unable to find an alternative folder name</source>
        <translation>Get ekki fundið annað möppunafn</translation>
    </message>
    <message>
        <source>Failed to add download task:
 %1</source>
        <translation>Mistókst að bæta við niðurhalsverki:
 %1</translation>
    </message>
    <message>
        <source>Failed to get repo download information:
%1</source>
        <translation>Mistókst að sækja niðurhalsgeymsluupplýsingar :
%1</translation>
    </message>
    <message>
        <source>Download Library</source>
        <translation>Hala niður safni</translation>
    </message>
    <message>
        <source>choose...</source>
        <translation>veldu...</translation>
    </message>
    <message>
        <source>Password for this library:</source>
        <translation>Lykilorð fyrir þetta safn:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Í lagi</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Hætta við</translation>
    </message>
</context>
<context>
    <name>EventDetailsDialog</name>
    <message>
        <source>Modification Details</source>
        <translation>Breytingar í smáatriðum</translation>
    </message>
</context>
<context>
    <name>EventDetailsListModel</name>
    <message>
        <source>Added files</source>
        <translation>Bætti við skrám</translation>
    </message>
    <message>
        <source>Deleted files</source>
        <translation>Eyddar skrár</translation>
    </message>
    <message>
        <source>Modified files</source>
        <translation>Breyttar skrár</translation>
    </message>
    <message>
        <source>Added folders</source>
        <translation>Nýjar möppur</translation>
    </message>
    <message>
        <source>Deleted folders</source>
        <translation>Eyddar möppur</translation>
    </message>
</context>
<context>
    <name>EventDetailsListView</name>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Opna</translation>
    </message>
    <message>
        <source>Open &amp;parent folder</source>
        <translation>Opna &amp;yfir skáasafn</translation>
    </message>
</context>
<context>
    <name>FileBrowserDialog</name>
    <message>
        <source>Cloud File Browser</source>
        <translation>Skýjavafri</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Til baka</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Áfram</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Heim</translation>
    </message>
    <message>
        <source>Upload files</source>
        <translation>Hlaða upp skrám</translation>
    </message>
    <message>
        <source>Upload a directory</source>
        <translation>Hlaða upp möppu</translation>
    </message>
    <message>
        <source>You don&apos;t have permission to upload files to this library</source>
        <translation>Þú hefur ekki réttindi til að upphlaða skrám í þetta safn</translation>
    </message>
    <message>
        <source>Create a folder</source>
        <translation>Búa til möppu</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Endurglæða</translation>
    </message>
    <message>
        <source>%1 items</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Folder name</source>
        <translation>Möppunafn</translation>
    </message>
    <message>
        <source>Invalid folder name!</source>
        <translation>Óleyfilegt möppunafn!</translation>
    </message>
    <message>
        <source>The name &quot;%1&quot; is already taken.</source>
        <translation>Þetta nafn &quot;%1&quot; er þegar í notkun.</translation>
    </message>
    <message>
        <source>retry</source>
        <translation>reyna aftur</translation>
    </message>
    <message>
        <source>Failed to get files information&lt;br/&gt;Please %1</source>
        <translation>Mistókst að sækja upplýsingar skáa&lt;br/&gt;Vinsamlegast %1</translation>
    </message>
    <message>
        <source>This folder is empty.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enter name of file to save to...</source>
        <translation>Sláðu inn nafn á skrá til að vista í...</translation>
    </message>
    <message>
        <source>Unable to remove file &quot;%1&quot;</source>
        <translation>Gat ekki fjarlægt skránna &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Enter the path of the folder you want to save to...</source>
        <translation>Sláðu inn slóð möppunnar sem þú vilt vista í...</translation>
    </message>
    <message>
        <source>Do you want to overwrite the existing file &quot;%1&quot;?</source>
        <translation>Vilti örugglega yfirskrifa núverandi skrá &quot;%1&quot;?</translation>
    </message>
    <message>
        <source>File &quot;%1&quot; haven&apos;t been synced</source>
        <translation>Skrá &quot;%1&quot; hefur ekki verið samstillt</translation>
    </message>
    <message>
        <source>File %1 already exists.&lt;br/&gt;Do you like to overwrite it?&lt;br/&gt;&lt;small&gt;(Choose No to upload using an alternative name).&lt;/small&gt;</source>
        <translation>Skrá %1 er þegar til.&lt;br/&gt;Viltu yfirskrifa hana?&lt;/br/&gt;&lt;/small&gt;(Veldu Nei til að hlaða upp með öðru nafni).&lt;/small&gt;</translation>
    </message>
    <message>
        <source>File does not exist</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to download file: %1</source>
        <translation>Mistókst að niðurhala skrá: %1</translation>
    </message>
    <message>
        <source>Select a file to upload</source>
        <translation>Veldu skrá til að hlaða upp</translation>
    </message>
    <message>
        <source>Select a directory to upload</source>
        <translation>Veldu möppu til að hlaða upp</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Endurnefna</translation>
    </message>
    <message>
        <source>Do you really want to delete these items</source>
        <translation>Viltu virkilega eyða þessum atriðum</translation>
    </message>
    <message>
        <source>Create folder failed</source>
        <translation>Mistókst að búa til möppu</translation>
    </message>
    <message>
        <source>Lock file failed</source>
        <translation>Læsing skráar mistókst</translation>
    </message>
    <message>
        <source>Select a file to update %1</source>
        <translation>Veldu skrá til að uppfæra %1</translation>
    </message>
    <message>
        <source>Rename failed</source>
        <translation>Endurnefning mistókst</translation>
    </message>
    <message>
        <source>Remove failed</source>
        <translation>Eyðing mistókst</translation>
    </message>
    <message>
        <source>Share failed</source>
        <translation>Deiling mistókst</translation>
    </message>
    <message>
        <source>Cannot paste files from the same folder</source>
        <translation>Get ekki sleppt skránum í sama skráasafn</translation>
    </message>
    <message>
        <source>Cannot paste the folder to its subfolder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Copy failed</source>
        <translation>Afritun mistókst</translation>
    </message>
    <message>
        <source>Move failed</source>
        <translation>Færsla mistókst</translation>
    </message>
    <message>
        <source>Create library failed!</source>
        <translation>Mistókst að búa til safn!</translation>
    </message>
    <message>
        <source>You do not have permission to upload to this folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Authorization expired</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Permission Error!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library/Folder not found.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to upload file %1: %2</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to create cache folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to open cache folder</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileBrowserProgressDialog</name>
    <message>
        <source>Pending</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Hætta við</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Upphlaða</translation>
    </message>
    <message>
        <source>Uploading %1</source>
        <translation>Hleð upp %1</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Niðurhala</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>Hala niður %1</translation>
    </message>
    <message>
        <source>%1 of %2</source>
        <translation>%1 af %2</translation>
    </message>
    <message>
        <source>Failed to upload file &quot;%1&quot;, do you want to retry?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Retry</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Skip</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Abort</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileNetworkTask</name>
    <message>
        <source>Operation canceled</source>
        <translation>Hætt við aðgerð</translation>
    </message>
    <message>
        <source>pending</source>
        <translation>yfirstandandi</translation>
    </message>
</context>
<context>
    <name>FileServerTask</name>
    <message>
        <source>task cancelled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internal Server Error</source>
        <translation>Innri Kerfisvilla</translation>
    </message>
    <message>
        <source>The storage quota has been used up</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileTableModel</name>
    <message>
        <source>locked by %1</source>
        <translation>læst af %1</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nafn</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Stærð</translation>
    </message>
    <message>
        <source>Last Modified</source>
        <translation>Síðast Breytt</translation>
    </message>
    <message>
        <source>Kind</source>
        <translation>Gerð</translation>
    </message>
</context>
<context>
    <name>FileTableView</name>
    <message>
        <source>&amp;Save As...</source>
        <translation>&amp;Vista sem...</translation>
    </message>
    <message>
        <source>&amp;Lock</source>
        <translation>&amp;Læsa</translation>
    </message>
    <message>
        <source>&amp;Rename</source>
        <translation>&amp;Endurnefna</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Eyða</translation>
    </message>
    <message>
        <source>Share to Group</source>
        <translation>Deila með Hópi</translation>
    </message>
    <message>
        <source>&amp;Update</source>
        <translation>&amp;Uppfæra</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Copy</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>Cu&amp;t</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>&amp;Paste</translation>
    </message>
    <message>
        <source>Canc&amp;el Download</source>
        <translation>Hætt&amp;a við niðurhal</translation>
    </message>
    <message>
        <source>&amp;Sync this folder</source>
        <translation>&amp;Samkeyra þessu skráasafni</translation>
    </message>
    <message>
        <source>This feature is available in pro version only
</source>
        <translation>Þessi virkni er aðeins aðgengileg í &quot;pro&quot; útgáfunni
</translation>
    </message>
    <message>
        <source>&amp;Generate %1 Download Link</source>
        <translation>&amp;Gera %1 Niðurhalshlekk</translation>
    </message>
    <message>
        <source>Share to User</source>
        <translation>Deila með Notanda</translation>
    </message>
    <message>
        <source>G&amp;enerate %1 Internal Link</source>
        <translation>G&amp;era %1 Innri Hlekk</translation>
    </message>
    <message>
        <source>&amp;Save As To...</source>
        <translation>&amp;Vista sem í...</translation>
    </message>
    <message>
        <source>Un&amp;lock</source>
        <translation>Af&amp;læsa</translation>
    </message>
    <message>
        <source>Unable to remove readonly files</source>
        <translation>Get ekki fjarlægt skrifvarnar skrár</translation>
    </message>
    <message>
        <source>Unable to cut readonly files</source>
        <translation>Get ekki klippt skrifvarðar skrár</translation>
    </message>
    <message>
        <source>Retry Upload</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete Local Version</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Local Version Save As...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open Local Cache Folder</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GetFileTask</name>
    <message>
        <source>Failed to create folders</source>
        <translation>Mistókst að búa til skráarsöfn</translation>
    </message>
    <message>
        <source>Failed to create temporary files</source>
        <translation>Mistókst að búa til tímabundna skrá</translation>
    </message>
    <message>
        <source>Failed to write file to disk</source>
        <translation>Mistókst að skrifa skrá á disk</translation>
    </message>
    <message>
        <source>Failed to remove the older version of the downloaded file</source>
        <translation>Mistókst að eyða eldri útgáfu af niðurhöluðu skránni</translation>
    </message>
    <message>
        <source>Failed to move file</source>
        <translation>Mistókst að færa skrá</translation>
    </message>
</context>
<context>
    <name>InitSeafileDialog</name>
    <message>
        <source>%1 Initialization</source>
        <translation>%1 Frumstillt</translation>
    </message>
    <message>
        <source>Choose %1 folder</source>
        <translation>Veldu %1 möppu</translation>
    </message>
    <message>
        <source>Please choose a directory</source>
        <translation>Vinsamlegast veldu skráarsafn</translation>
    </message>
    <message>
        <source>Initialization is not finished. Really quit?</source>
        <translation>Frumstillingu er ekki lokið. Virkilega hætta núna?</translation>
    </message>
    <message>
        <source>The folder %1 does not exist</source>
        <translation>Skráarsafnið %1 er ekki til</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Svargluggi</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>logo</translation>
    </message>
    <message>
        <source>Choose a folder</source>
        <translation>Veldu möppu</translation>
    </message>
    <message>
        <source>Please choose a folder. We will create a %1 subfolder in it. When you download a library, it will be saved there by default.</source>
        <translation>Vinsamlegast veldu möppu. Við munum búa til %1 undirmöppu í henni. Þegar þú halar niður safni, þá er það sjálfgefið að vista þar.</translation>
    </message>
    <message>
        <source>Choose...</source>
        <translation>Veldu...</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Næsta</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Hætta við</translation>
    </message>
</context>
<context>
    <name>InitVirtualDriveDialog</name>
    <message>
        <source>%1 organizes files by libraries.
Do you like to download your default library?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Checking your default library...</source>
        <translation>Athuga sjálfgefna skráarsafnið þitt...</translation>
    </message>
    <message>
        <source>Creating the default library...</source>
        <translation>Bý til sjálfgefna safnið...</translation>
    </message>
    <message>
        <source>Failed to create default library:

The server version must be 2.1 or higher to support this.</source>
        <translation>Mistókst að eyða sjálfgefnu safni:

Þjónsútgáfan verður að vera 2.1 eða hærri til að styðja þetta</translation>
    </message>
    <message>
        <source>Failed to get default library:
%1</source>
        <translation>Mistókst að sækja sjálfgefið safn:
%1</translation>
    </message>
    <message>
        <source>Failed to create default library:
%1</source>
        <translation>Mistókst að búa til sjálfgefið safn:
%1</translation>
    </message>
    <message>
        <source>Downloading default library...</source>
        <translation>Hala niður sjálfgefna safninu...</translation>
    </message>
    <message>
        <source>Failed to download default library:
%1</source>
        <translation>Mistókst að hala niður sjálfgefnu safni:
%1</translation>
    </message>
    <message>
        <source>The default library has been downloaded.
You can click the &quot;Open&quot; button to view it.</source>
        <translation>Sjálfgefna safninu hefur verið halað niður.
Þú getur smellt á &quot;Opna&quot; takkann til að skoða það.</translation>
    </message>
    <message>
        <source>Error when downloading the default library: %1</source>
        <translation>Villa þegar verið var að hala niður sjálfgefna safninu: %1</translation>
    </message>
    <message>
        <source>Failed to download default library:
 %1</source>
        <translation>Mistókst að hala niður sjálfgefnu safni:
 %1</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Samræður</translation>
    </message>
    <message>
        <source>%1 organizes files by libraries. 
Do you like to download your default library?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Skip</source>
        <translation>Sleppa</translation>
    </message>
    <message>
        <source>Run in Background</source>
        <translation>Keyra í Bakgrunni</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Opna</translation>
    </message>
    <message>
        <source>Finish</source>
        <translation>Enda</translation>
    </message>
    <message>
        <source>Download Default Library</source>
        <translation>Hala niður Sjálfgefnu Safni</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Já</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>logo</translation>
    </message>
</context>
<context>
    <name>LoadMoreButton</name>
    <message>
        <source>load more</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LoginDialog</name>
    <message>
        <source>Add an account</source>
        <translation>Bæta við reikningi</translation>
    </message>
    <message>
        <source>Single Sign On</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Re-login</source>
        <translation>Endur-innskráning</translation>
    </message>
    <message>
        <source>Logging in...</source>
        <translation>Er að innskrá...</translation>
    </message>
    <message>
        <source>Network Error:
 %1</source>
        <translation>Netvilla:
 %1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Warning:&lt;/b&gt; The ssl certificate of this server is not trusted, proceed anyway?</source>
        <translation>&lt;b&gt;Viðvörun:&lt;/b&gt; ssl skilríkið fyrir þennan þjón er ótreyst, halda samt áfram?</translation>
    </message>
    <message>
        <source>Please enter the server address</source>
        <translation>Vinsamlegst sláðu inn veffang þjóns</translation>
    </message>
    <message>
        <source>%1 is not a valid server address</source>
        <translation>%1 er ekki gilt vefang þjóns</translation>
    </message>
    <message>
        <source>Please enter the username</source>
        <translation>Vinsamlegst sláðu inn notendanafn</translation>
    </message>
    <message>
        <source>Please enter the computer name</source>
        <translation>Vinsamlegast skráðu heiti tölvunnar</translation>
    </message>
    <message>
        <source>Failed to save current account</source>
        <translation>Mistókst að vista reikninginn</translation>
    </message>
    <message>
        <source>Two Factor Authentication</source>
        <translation>Tveggja Skrefa Auðkenning</translation>
    </message>
    <message>
        <source>%1 Server Address</source>
        <translation>%1 Veffang Þjóns</translation>
    </message>
    <message>
        <source>Server address must not be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 is not a valid server address. It has to start with &apos;https://&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please enter the password</source>
        <translation>Vinsamlegast sláðu inn lykilorð</translation>
    </message>
    <message>
        <source>Enter the two factor authentication token</source>
        <translation>Sláðu inn tveggja skrefa aukennislykilinn</translation>
    </message>
    <message>
        <source>Incorrect email or password</source>
        <translation>Ekki rétt netfang eða lykilorð</translation>
    </message>
    <message>
        <source>Logging in too frequently, please wait a minute</source>
        <translation>Ert að skrá þig inn of ört, vinsamlegast bíddu aðeins</translation>
    </message>
    <message>
        <source>Internal Server Error</source>
        <translation>Innri Kerfisvilla</translation>
    </message>
    <message>
        <source>Failed to login: %1</source>
        <translation>Innskráning mistókst: %1</translation>
    </message>
    <message>
        <source>Failed to login</source>
        <translation>Innskráning mistókst</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Svargluggi</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>logo</translation>
    </message>
    <message>
        <source>Server:</source>
        <translation>Þjónn:</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;For example: https://seacloud.cc&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Til dæmis: https://seacloud.cc&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>or http://192.168.1.24:8000</source>
        <translation>eða http://192.168.1.24:8000</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Lykilorð:</translation>
    </message>
    <message>
        <source>status text</source>
        <translation>stöðutexti</translation>
    </message>
    <message>
        <source>Computer Name:</source>
        <translation>Tölvunafn:</translation>
    </message>
    <message>
        <source>Email / Username:</source>
        <translation>Netfang / Notendanafn:</translation>
    </message>
    <message>
        <source>e.g. Jim&apos;s laptop</source>
        <translation>t.d Siggu tölva</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Innskrá</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Hætta við</translation>
    </message>
</context>
<context>
    <name>LogoutView</name>
    <message>
        <source>You are logout. Please </source>
        <translation>Þú er útskráð(ur). Vinsamlegast</translation>
    </message>
    <message>
        <source>login</source>
        <translation>innskrá</translation>
    </message>
    <message>
        <source>Add an account</source>
        <translation>Bæta við reikningi</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Refresh</source>
        <translation>Endurglæða</translation>
    </message>
</context>
<context>
    <name>MessageListener</name>
    <message>
        <source>failed to load ccnet config dir </source>
        <translation>mistókst að sækja ccnet stillingarskráarsafn</translation>
    </message>
    <message>
        <source>&quot;%1&quot; is unsynced. 
Reason: Deleted on server</source>
        <translation>&quot;%1&quot; er ósamstillt. 
Ástæða: Eytt út á þjóni</translation>
    </message>
    <message>
        <source>&quot;%1&quot; is synchronized</source>
        <translation>&quot;%1&quot; er samstillt</translation>
    </message>
    <message>
        <source>Files uploaded to &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File %1 conflict</source>
        <translation>Rekst á við skránna %1</translation>
    </message>
    <message>
        <source>Failed to sync file %1
File is locked by other application. This file will be updated when you close the application.</source>
        <translation>Mistókst að samstilla skrá %1
Skránni er læst af öðru forriti. Þessi skrá verður uppfærð þegar þú lokar forritinu.</translation>
    </message>
    <message>
        <source>Failed to sync folder %1
Some file in this folder is locked by other application. This folder will be updated when you close the application.</source>
        <translation>Mistókst að samstilla skráasafn %1
Einhverjum skrám í þessu skráasafni er læst af öðrum forritum. Þetta skráasafn verður uppfært þegar þú lokar þeim forritum.</translation>
    </message>
    <message>
        <source>Failed to sync file %1
File is locked by other user on the server. Update to this file is not uploaded.</source>
        <translation>Mistókst að samstilla skrá %1
Skránni er læst af öðrum notanda á þjóninum. Uppfærslu á þessari skrá er ekki hlaðið upp.</translation>
    </message>
    <message>
        <source>Failed to sync %1
File path is ended with space or period and cannot be created on Windows.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to sync %1
File path contains invalid characters. It is not synced to this computer.</source>
        <translation>Mistókst að samstilla %1
Skráarslóð inniheldur ólöglega stafi. Henni er ekki samstillt við þessa tölvu.</translation>
    </message>
    <message>
        <source>Failed to index file %1
Please check file permission and disk space.</source>
        <translation>Mistókst að skrá skránna %1
Vinsamlegast athugaðu skráarleyfi og diskapláss.</translation>
    </message>
    <message>
        <source>&quot;%1&quot; failed to sync. 
Access denied to service</source>
        <translation>&quot;%1&quot; tókst ekki að samstilla. 
Aðgangur óheimill á þjóni</translation>
    </message>
    <message>
        <source>&quot;%1&quot; failed to sync.
The library owner&apos;s storage space is used up.</source>
        <translation>&quot;%1&quot; tókst ekki að samstilla.
Geymslupláss eiganda safnsins er orðið fullt.</translation>
    </message>
</context>
<context>
    <name>PrivateShareDialog</name>
    <message>
        <source>Share %1</source>
        <translation>Deila %1</translation>
    </message>
    <message>
        <source>Enter the group name</source>
        <translation>Sláðu inn nafn hópsins</translation>
    </message>
    <message>
        <source>Enter user name or email address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Updated successfully</source>
        <translation>Tókst að hlaða upp</translation>
    </message>
    <message>
        <source>Share Operation Failed: %1</source>
        <translation>Deiliaðgerð mistókst: %1</translation>
    </message>
    <message>
        <source>Removed successfully</source>
        <translation>Tókst að fjarlægja</translation>
    </message>
    <message>
        <source>Failed to get share information of the folder</source>
        <translation>Mistókst að sækja upplýsingar um möppuna</translation>
    </message>
    <message>
        <source>Failed to get your groups and contacts information</source>
        <translation>Mistókst að sækja hópa og tengiliðstupplýsingarnar þínar</translation>
    </message>
    <message>
        <source>Please enter the username</source>
        <translation>Vinsamlegast sláðu inn notendanafnið</translation>
    </message>
    <message>
        <source>Please enter the group name</source>
        <translation>Vinsamlegast sláðu inn hópanafnið</translation>
    </message>
    <message>
        <source>No such group &quot;%1&quot;</source>
        <translation>Enginn slíkur hópur &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Already shared to group %1</source>
        <translation>Þegar deilt með hópi %1</translation>
    </message>
    <message>
        <source>Already shared to user %1</source>
        <translation>Þegar deilt með notanda %1</translation>
    </message>
    <message>
        <source>The previous operation is still in progres</source>
        <translation>Síðasta aðgerð er enn í vinnslu</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Samræður</translation>
    </message>
    <message>
        <source>Share To:</source>
        <translation>Deila Með:</translation>
    </message>
    <message>
        <source>Share</source>
        <translation>Deila</translation>
    </message>
    <message>
        <source>Permission:</source>
        <translation>Réttindi:</translation>
    </message>
    <message>
        <source>Read-Write</source>
        <translation>Lesa-Skrifa</translation>
    </message>
    <message>
        <source>Read-Only</source>
        <translation>Aðeins-Lesa</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Loka</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>synchronized</source>
        <translation>samstillt</translation>
    </message>
    <message>
        <source>indexing files</source>
        <translation>Bý til yfirlit yfir skrár</translation>
    </message>
    <message>
        <source>sync initializing</source>
        <translation>frumstilli samstillingu</translation>
    </message>
    <message>
        <source>downloading</source>
        <translation>hala niður</translation>
    </message>
    <message>
        <source>uploading</source>
        <translation>hleð upp</translation>
    </message>
    <message>
        <source>sync merging</source>
        <translation>sameina samstillingar</translation>
    </message>
    <message>
        <source>waiting for sync</source>
        <translation>bíð eftir samstilingu</translation>
    </message>
    <message>
        <source>server not connected</source>
        <translation>þjónn ekki tengdur</translation>
    </message>
    <message>
        <source>server authenticating</source>
        <translation>auðkenning þjóns</translation>
    </message>
    <message>
        <source>auto sync is turned off</source>
        <translation>slökkt er á sjálfvirkri samstillingu</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>óþekkt</translation>
    </message>
    <message>
        <source>Server has been removed</source>
        <translation>Þjónninn hefur verið fjarlægður</translation>
    </message>
    <message>
        <source>You have not logged in to the server</source>
        <translation>Þú hefur ekki skráð þig inn</translation>
    </message>
    <message>
        <source>You do not have permission to access this library</source>
        <translation>Þú hefur ekki aðgangsleyfi að þessu safni</translation>
    </message>
    <message>
        <source>The storage space of the library owner has been used up</source>
        <translation>Geymslupláss eiganda þessa safns er fullt</translation>
    </message>
    <message>
        <source>Remote service is not available</source>
        <translation>Fjarþjónusta er ekki í boði</translation>
    </message>
    <message>
        <source>Access denied to service</source>
        <translation>Aðgangur að þjónustu óheimil</translation>
    </message>
    <message>
        <source>Internal data corrupted</source>
        <translation>Sködduð innri gögn</translation>
    </message>
    <message>
        <source>Failed to start upload</source>
        <translation>Upphleðsla mistókst</translation>
    </message>
    <message>
        <source>Error occured in upload</source>
        <translation>Villa í upphleðslu</translation>
    </message>
    <message>
        <source>Failed to start download</source>
        <translation>Mistókst að niðurhala</translation>
    </message>
    <message>
        <source>Error occured in download</source>
        <translation>Villa í niðurhali</translation>
    </message>
    <message>
        <source>Library is damaged on server</source>
        <translation>Safn er skaddað á þjóni</translation>
    </message>
    <message>
        <source>Conflict in merge</source>
        <translation>Misræmi í sameiningu</translation>
    </message>
    <message>
        <source>Server version is too old</source>
        <translation>Útgáfa á þjóni er of gömul</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Óþekkt villa</translation>
    </message>
    <message>
        <source>Permission denied on server. Please try resync the library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Network error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cannot resolve proxy address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cannot resolve server address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cannot connect to server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to establish secure connection. Please check server SSL certificate</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Data transfer was interrupted. Please check network or firewall</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Data transfer timed out. Please check network or firewall</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unhandled http redirect from server. Please check server cofiguration</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Server error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Bad request</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internal data corrupt on the client. Please try resync the library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Not enough memory</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to write data on the client. Please check disk space or folder permissions</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Storage quota full</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library deleted on server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library damaged on server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The storage quota has been used up</source>
        <translation>Geymslukvóti hefur verið fullnýttur</translation>
    </message>
    <message>
        <source>Internal server error</source>
        <translation>Innri kerfisvilla</translation>
    </message>
    <message>
        <source>Your %1 client is too old</source>
        <translation>%1 biðlarinn þinn er of gamall</translation>
    </message>
    <message>
        <source>Failed to sync this library</source>
        <translation>Mistókst að samstilla þetta safn</translation>
    </message>
    <message>
        <source>Files are locked by other application</source>
        <translation>Skrár eru læstar af öðru forriti</translation>
    </message>
    <message>
        <source>Library is deleted on server</source>
        <translation>Safni er eytt á þjóni</translation>
    </message>
    <message>
        <source>Error when accessing the local folder</source>
        <translation>Það kom upp villa þegar reynt var að tengjast skráarsafni á tölvunni þinni</translation>
    </message>
    <message>
        <source>initializing...</source>
        <translation>Frumstilli...</translation>
    </message>
    <message>
        <source>Failed to index local files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to check server information</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to create local files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to merge local file changes</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Incorrect password. Please download again</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internal error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>connecting server...</source>
        <translation>tengist þjóni...</translation>
    </message>
    <message>
        <source>indexing files...</source>
        <translation>Bý til yfirlit yfir skár...</translation>
    </message>
    <message>
        <source>Downloading file list...</source>
        <translation>Hala niður skráalista...</translation>
    </message>
    <message>
        <source>Downloading files...</source>
        <translation>Hala niður skrám...</translation>
    </message>
    <message>
        <source>Creating folder...</source>
        <translation>Bý til skráarsafn...</translation>
    </message>
    <message>
        <source>Merge file changes...</source>
        <translation>Sameina skráarbreytingar...</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Búin</translation>
    </message>
    <message>
        <source>checking server info...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Canceling</source>
        <translation>Hætta við</translation>
    </message>
    <message>
        <source>Canceled</source>
        <translation>Hætt við</translation>
    </message>
    <message>
        <source>SSL Error</source>
        <translation>SSL Villa</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Netvilla: %1</translation>
    </message>
    <message>
        <source>Server Error</source>
        <translation>Kerfisvilla</translation>
    </message>
    <message>
        <source>failed to open certs database</source>
        <translation>mistókst að opna vottorðagagnagrunn</translation>
    </message>
    <message>
        <source>File &quot;%1&quot; doesn&apos;t exist in &quot;%2&quot;</source>
        <translation>Skrá &quot;%1&quot; er ekki til í &quot;%2&quot;</translation>
    </message>
    <message>
        <source>%1 couldn&apos;t find an application to open file %2</source>
        <translation>%1 gat ekki fundið forrit til að opna skránna %2</translation>
    </message>
    <message>
        <source>Created library &quot;%1&quot;</source>
        <translation>Bjó til safnið &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Deleted library &quot;%1&quot;</source>
        <translation>Eyddi safninu &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Rename %1 to</source>
        <translation>Endurnefna %1 sem</translation>
    </message>
    <message>
        <source>Unable to download item &quot;%1&quot;</source>
        <translation>Gat ekki niðurhalað atriði &quot;%1&quot;</translation>
    </message>
    <message>
        <source>copy failed</source>
        <translation>afritun mistókst</translation>
    </message>
    <message>
        <source>Added</source>
        <translation>Bætt við</translation>
    </message>
    <message>
        <source>Deleted</source>
        <translation>Eytt</translation>
    </message>
    <message>
        <source>Removed</source>
        <translation>Fjarlægt</translation>
    </message>
    <message>
        <source>Modified</source>
        <translation>Breytt</translation>
    </message>
    <message>
        <source>Renamed</source>
        <translation>Endurnefnt</translation>
    </message>
    <message>
        <source>Added or modified</source>
        <translation>Bætt við eða breytt</translation>
    </message>
    <message>
        <source>Moved</source>
        <translation>Fært</translation>
    </message>
    <message>
        <source>Added directory</source>
        <translation>Bætti við skráarsafni</translation>
    </message>
    <message>
        <source>Removed directory</source>
        <translation>Fjarlægði skráarsafn</translation>
    </message>
    <message>
        <source>Renamed directory</source>
        <translation>Endurnefndi skráarsafn</translation>
    </message>
    <message>
        <source>Moved directory</source>
        <translation>Færði skráarsafn</translation>
    </message>
    <message>
        <source>files</source>
        <translation>skrár</translation>
    </message>
    <message>
        <source>directories</source>
        <translation>skráarsöfn</translation>
    </message>
    <message>
        <source>and %1 more</source>
        <translation>og %1 fleiri</translation>
    </message>
    <message>
        <source>Reverted library to status at</source>
        <translation>Setti stöðu safns á</translation>
    </message>
    <message>
        <source>Reverted file &quot;%1&quot; to status at %2.</source>
        <translation>Snéri skrá &quot;%1&quot; aftur í stöðu &quot;%2&quot; </translation>
    </message>
    <message>
        <source>Recovered deleted directory</source>
        <translation>Endurheimti eyddu skráarsafni</translation>
    </message>
    <message>
        <source>Changed library name or description</source>
        <translation>Breytti nafni eða lýsingu skráarsafns</translation>
    </message>
    <message>
        <source>Auto merge by %1 system</source>
        <translation>Sameinað sjálfvirkt af %1 kerfi</translation>
    </message>
    <message>
        <source>Just now</source>
        <translation>Rétt í þessu</translation>
    </message>
    <message>
        <source>1 day ago</source>
        <translation>Fyrir einum degi síðan</translation>
    </message>
    <message>
        <source>%1 days ago</source>
        <translation>Fyrir %1 dögum síðan</translation>
    </message>
    <message>
        <source>1 hour ago</source>
        <translation>Fyrir einni klukkustund síðan</translation>
    </message>
    <message>
        <source>%1 hours ago</source>
        <translation>Fyrir %1 klukkustundum síðan</translation>
    </message>
    <message>
        <source>1 minute ago</source>
        <translation>Fyrir einni mínútu síðan</translation>
    </message>
    <message>
        <source>%1 minutes ago</source>
        <translation>Fyrir %1 mínútum síðan</translation>
    </message>
    <message>
        <source>&lt;Not Part of Certificate&gt;</source>
        <translation>&lt;Not Part of Certificate&gt;</translation>
    </message>
    <message>
        <source>Found another running process of %1, kill it and start a new one?</source>
        <translation>Fann aðra keyrslu í gangi af %1, slökkva á henni og ræsa nýja?</translation>
    </message>
    <message>
        <source>Unable to start %1 due to the failure of shutting down the previous process</source>
        <translation>Gat ekki ræst %1 vegna villu við að slökkva á fyrri keyrslum</translation>
    </message>
    <message>
        <source>Sync this library to:</source>
        <translation>Samkeyra þessu safni með:</translation>
    </message>
    <message>
        <source>Sync this folder to:</source>
        <translation>Samkeyra þessu skráasafni með:</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Skráasafn</translation>
    </message>
    <message>
        <source>Readonly Folder</source>
        <translation>Skrifvarið Skráasafn</translation>
    </message>
    <message>
        <source>Document</source>
        <translation>Skjal</translation>
    </message>
    <message>
        <source>PDF Document</source>
        <translation>PDF Skjal</translation>
    </message>
    <message>
        <source>Image File</source>
        <translation>Myndaskrá</translation>
    </message>
    <message>
        <source>Text Document</source>
        <translation>Textaskjal</translation>
    </message>
    <message>
        <source>Audio File</source>
        <translation>Hljóðskrá</translation>
    </message>
    <message>
        <source>Video File</source>
        <translation>Vídeóskrá</translation>
    </message>
    <message>
        <source>Word Document</source>
        <translation>Word skjal</translation>
    </message>
    <message>
        <source>PowerPoint Document</source>
        <translation>PowerPoint skjal</translation>
    </message>
    <message>
        <source>Excel Document</source>
        <translation>Excel skjal</translation>
    </message>
    <message>
        <source>The path &quot;%1&quot; conflicts with system path</source>
        <translation>Slóðin &quot;%1&quot; rekst á við kerfisslóð</translation>
    </message>
    <message>
        <source>The path &quot;%1&quot; conflicts with an existing library</source>
        <translation>Slóðin &quot;%1&quot; rekst á við safn sem þegar er til</translation>
    </message>
    <message>
        <source>uploading file list</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File is locked by another application</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Folder is locked by another application</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File is locked by another user</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Path is invalid</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Error when indexing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Path ends with space or period character</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Path contains invalid characters like &apos;|&apos; or &apos;:&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>failed to open file cache database</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library name contains invalid characters such as &apos;:&apos;, &apos;*&apos;, &apos;|&apos;, &apos;?&apos;</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ReliablePostFileTask</name>
    <message>
        <source>File does not exist</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RepoDetailDialog</name>
    <message>
        <source>Library &quot;%1&quot;</source>
        <translation>Safn &quot;%1&quot;</translation>
    </message>
    <message>
        <source>This library is not downloaded yet</source>
        <translation>Ekki er enn búið að hala niður þessu safni</translation>
    </message>
    <message>
        <source>Error: </source>
        <translation>Villa:</translation>
    </message>
    <message>
        <source>every %1 seconds</source>
        <translation>hverjar %1 sekúndur</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Svargluggi</translation>
    </message>
    <message>
        <source>RepoIcon</source>
        <translation>SafnaSmámynd</translation>
    </message>
    <message>
        <source>RepoName</source>
        <translation>SafnaNafn</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Lýsing:</translation>
    </message>
    <message>
        <source>TextLabel</source>
        <translation>TextaMerki</translation>
    </message>
    <message>
        <source>Owner:</source>
        <translation>Eigandi:</translation>
    </message>
    <message>
        <source>Last Modified:</source>
        <translation>Síðast Breytt:</translation>
    </message>
    <message>
        <source>mtime</source>
        <translation>mtime</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Stærð:</translation>
    </message>
    <message>
        <source>Local Path:</source>
        <translation>Staðvær Slóð:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Staða:</translation>
    </message>
    <message>
        <source>RepoStatus</source>
        <translation>SafnaStaða</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nafn:</translation>
    </message>
    <message>
        <source>Sync Interval:</source>
        <translation>Samstillingartíðni:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Loka</translation>
    </message>
</context>
<context>
    <name>RepoItemDelegate</name>
    <message>
        <source>, %1%2</source>
        <translation>, %1%2</translation>
    </message>
    <message>
        <source>, %1</source>
        <translation>, %1</translation>
    </message>
    <message>
        <source>This library has not been downloaded</source>
        <translation>Þessu safni hefur ekki enn verið halað niður</translation>
    </message>
</context>
<context>
    <name>RepoService</name>
    <message>
        <source>Unable to open file &quot;%1&quot; from nonexistent library &quot;%2&quot;</source>
        <translation>Get ekki opnað skrá &quot;%1&quot; því safnið &quot;%2&quot; er ekki til</translation>
    </message>
</context>
<context>
    <name>RepoTreeModel</name>
    <message>
        <source>Recently Updated</source>
        <translation>Nýlega Uppfært</translation>
    </message>
    <message>
        <source>My Libraries</source>
        <translation>Söfnin mín</translation>
    </message>
    <message>
        <source>Sub Libraries</source>
        <translation>Undirsöfn</translation>
    </message>
    <message>
        <source>Shared with me</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared with all</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared with groups</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Synced Libraries</source>
        <translation>Samstillt Söfn</translation>
    </message>
    <message>
        <source>sync initializing</source>
        <translation>frumstilli samstillingu</translation>
    </message>
</context>
<context>
    <name>RepoTreeView</name>
    <message>
        <source>Disable auto sync</source>
        <translation>Afvirkja sjálfvirka samstillingu</translation>
    </message>
    <message>
        <source>Enable auto sync</source>
        <translation>Virkja sjálfvirka samstillingu</translation>
    </message>
    <message>
        <source>Show &amp;details</source>
        <translation>Sýna &amp;smáatriði</translation>
    </message>
    <message>
        <source>Show details of this library</source>
        <translation>Sýna smáatriði varðandi þetta safn</translation>
    </message>
    <message>
        <source>&amp;Sync this library</source>
        <translation>&amp;Samstilla þetta safn</translation>
    </message>
    <message>
        <source>Sync this library</source>
        <translation>Samstilla þetta safn</translation>
    </message>
    <message>
        <source>Recently Updated</source>
        <translation>Nýlega Uppfært</translation>
    </message>
    <message>
        <source>Sync &amp;now</source>
        <translation>Samkeyra &amp;núna</translation>
    </message>
    <message>
        <source>Sync this library immediately</source>
        <translation>Samkeyra þetta safn núna</translation>
    </message>
    <message>
        <source>&amp;Cancel download</source>
        <translation>&amp;Hætta við niðurhal</translation>
    </message>
    <message>
        <source>Cancel download of this library</source>
        <translation>Hætta við niðurhal á þessu safni</translation>
    </message>
    <message>
        <source>&amp;Open folder</source>
        <translation>&amp;Opna skráarsafn</translation>
    </message>
    <message>
        <source>open local folder</source>
        <translation>opna staðvært skráarsafn</translation>
    </message>
    <message>
        <source>&amp;Open local folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Unsync</source>
        <translation>&amp;Samstilling Af</translation>
    </message>
    <message>
        <source>unsync this library</source>
        <translation>aftengja þetta safn</translation>
    </message>
    <message>
        <source>&amp;View on cloud</source>
        <translation>&amp;Skoða í skýi</translation>
    </message>
    <message>
        <source>view this library on seahub</source>
        <translation>skoða þetta safn á seahub</translation>
    </message>
    <message>
        <source>Share to user</source>
        <translation>Deila með notanda</translation>
    </message>
    <message>
        <source>Share this library to a user</source>
        <translation>Deila þessu safni með notanda</translation>
    </message>
    <message>
        <source>Share to group</source>
        <translation>Deila með hópi</translation>
    </message>
    <message>
        <source>Share this library to a group</source>
        <translation>Deila þessu safni með hópi</translation>
    </message>
    <message>
        <source>&amp;Open cloud file browser</source>
        <translation>&amp;Opna skráavafra skýs</translation>
    </message>
    <message>
        <source>open this library in embedded Cloud File Browser</source>
        <translation>opna þetta safn í innbyggðum Skráavafra Skýs </translation>
    </message>
    <message>
        <source>&amp;Leave share</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>leave share</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Resync this library</source>
        <translation>&amp;Endursamstilla þetta safn</translation>
    </message>
    <message>
        <source>unsync and resync this library</source>
        <translation>Taka af og setja aftur á samstillingu fyrir þetta safn</translation>
    </message>
    <message>
        <source>Set sync &amp;Interval</source>
        <translation>Setja &amp;samstillingartíðni</translation>
    </message>
    <message>
        <source>set sync interval for this library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure to unsync the library &quot;%1&quot;?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure to resync the library &quot;%1&quot;?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure to overwrite the file &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to unsync library &quot;%1&quot;</source>
        <translation>Mistókst að aftengja safnið &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Are you sure you want to leave the share &quot;%1&quot;?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Leaving share failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to cancel this task:

 %1</source>
        <translation>Mistókst að hætta við þetta verk:

 %1</translation>
    </message>
    <message>
        <source>The download has been canceled</source>
        <translation>Hætt var við niðurhalið</translation>
    </message>
    <message>
        <source>You do not have permission to upload to this folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to overwrite file &quot;%1&quot; with itself</source>
        <translation>Gat ekki yfirskrifað skrána &quot;%1&quot; með sjálfri sér</translation>
    </message>
    <message>
        <source>Unable to delete file &quot;%1&quot;</source>
        <translation>Gat ekki eytt skránni &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Failed to upload file: %1</source>
        <translation>Mistókst að hlaða upp skránni: %1</translation>
    </message>
    <message>
        <source>Sync Interval (In seconds):</source>
        <translation>Samstillinartíðni (í sekúndum):</translation>
    </message>
    <message>
        <source>Set Sync Internval For Library &quot;%1&quot;</source>
        <translation>Setja Samstillingartíðni Fyrir Safn &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>ReposTab</name>
    <message>
        <source>Search libraries</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>retry</source>
        <translation>reyna aftur</translation>
    </message>
    <message>
        <source>Failed to get libraries information&lt;br/&gt;Please %1</source>
        <translation>Tókst ekki að sækja upplýsingar um safn&lt;br/&gt;Vinsamlegast %1</translation>
    </message>
</context>
<context>
    <name>SeafileApiClient</name>
    <message>
        <source>&lt;b&gt;Warning:&lt;/b&gt; The ssl certificate of this server is not trusted, proceed anyway?</source>
        <translation>&lt;b&gt;Viðvörun:&lt;/b&gt; ssl skírteinið fyrir þennan þjón er ekki traust, halda samt áfram?</translation>
    </message>
</context>
<context>
    <name>SeafileApplet</name>
    <message>
        <source>failed to add default account</source>
        <translation>mistókst að bæta við sjálfgefnum reikningi</translation>
    </message>
    <message>
        <source>Failed to initialize log: %s</source>
        <translation>Mistókst að frumstilla skrá: %s</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Í lagi</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Já</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nei</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Hætta við</translation>
    </message>
</context>
<context>
    <name>SeafileLinkDialog</name>
    <message>
        <source>%1 Internal Link</source>
        <translation>%1 Innri Hlekkur</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Afrita í skyndimynni</translation>
    </message>
    <message>
        <source>%1 Web Link:</source>
        <translation>%1 Vef Hlekkur:</translation>
    </message>
    <message>
        <source>%1 Protocol Link:</source>
        <translation>%1 Regluhlekkur:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Í Lagi</translation>
    </message>
</context>
<context>
    <name>SeafileRpcClient</name>
    <message>
        <source>failed to load ccnet config dir %1</source>
        <translation>mistókst að bæta við ccnet styllingarskráarsafni %1</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Óþekkt villa</translation>
    </message>
</context>
<context>
    <name>SeafileTrayIcon</name>
    <message>
        <source>Disable auto sync</source>
        <translation>Skökkva á sjálfvirkri samstillingu</translation>
    </message>
    <message>
        <source>Enable auto sync</source>
        <translation>Kveikja á sjálfvirkri samstillingu</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Hætta</translation>
    </message>
    <message>
        <source>Show main window</source>
        <translation>Sýna aðalglugga</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Stillingar</translation>
    </message>
    <message>
        <source>Open %1 &amp;folder</source>
        <translation>Opna %1 &amp;skráasafn</translation>
    </message>
    <message>
        <source>open %1 folder</source>
        <translation>opna %1 skáasafn</translation>
    </message>
    <message>
        <source>Open &amp;logs folder</source>
        <translation>Opna skráarsafn &amp;skráninga</translation>
    </message>
    <message>
        <source>Show file sync errors</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Um</translation>
    </message>
    <message>
        <source>Show the application&apos;s About box</source>
        <translation>Sýna upplýsingar um forritið</translation>
    </message>
    <message>
        <source>&amp;Online help</source>
        <translation>&amp;Hjálp á netinu</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Skrá</translation>
    </message>
    <message>
        <source>auto sync is disabled</source>
        <translation>slökkt er á sjálfvirkri samstillingu</translation>
    </message>
    <message>
        <source>Uploading</source>
        <translation>Hleð upp</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Hala niður</translation>
    </message>
    <message>
        <source>open %1 log folder</source>
        <translation>opna %1 sögu skráasafns</translation>
    </message>
    <message>
        <source>open %1 online help</source>
        <translation>opna %1 hjálp á netinu</translation>
    </message>
    <message>
        <source>some servers not connected</source>
        <translation>sumir þjónar ekki tengdir</translation>
    </message>
</context>
<context>
    <name>SearchResultListView</name>
    <message>
        <source>&amp;Show in folder</source>
        <translation>&amp;Sýna í skráasafni</translation>
    </message>
    <message>
        <source>Show in folder</source>
        <translation>Sýna í skráasafni</translation>
    </message>
</context>
<context>
    <name>SearchTab</name>
    <message>
        <source>Search files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>retry</source>
        <translation>reyna aftur</translation>
    </message>
    <message>
        <source>Failed to search&lt;br/&gt;Please %1</source>
        <translation>Leit mistókst&lt;br/&gt;Vinsamlega %1</translation>
    </message>
</context>
<context>
    <name>ServerStatusDialog</name>
    <message>
        <source>Servers connection status</source>
        <translation>Tengistaða þjóns</translation>
    </message>
    <message>
        <source>connected</source>
        <translation>tengt</translation>
    </message>
    <message>
        <source>disconnected</source>
        <translation>aftengt</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Samræða</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Loka</translation>
    </message>
</context>
<context>
    <name>SetRepoPasswordDialog</name>
    <message>
        <source>Please provide the library password</source>
        <translation>Vinsamlegast sláðu inn lykilorð safnsins</translation>
    </message>
    <message>
        <source>Provide the password for library %1</source>
        <translation>Sláðu inn lykilorð fyrir safnið %1</translation>
    </message>
    <message>
        <source>Please enter the password</source>
        <translation>Vinsamlegast sláðu inn lykilorð</translation>
    </message>
    <message>
        <source>Incorrect password</source>
        <translation>Rangt lykilorð</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Óþekkt villa</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Samræður</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Í lagi</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Hætta við</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>Stillingar</translation>
    </message>
    <message>
        <source>Auto start %1 after login</source>
        <translation>Keyra %1 upp sjálfvirkt eftir innskráningu</translation>
    </message>
    <message>
        <source>Hide %1 Icon from the dock</source>
        <translation>Fela %1 smámynd frá stjórnstiku</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ekkert</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP Proxy</translation>
    </message>
    <message>
        <source>Socks5 Proxy</source>
        <translation>Socks5 Proxy</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Proxy Kerfi</translation>
    </message>
    <message>
        <source>You have changed languange. Restart to apply it?</source>
        <translation>Þú hefur skipt um tungumál. Endurræsa til að virkja það?</translation>
    </message>
    <message>
        <source>The proxy host address can&apos;t be empty</source>
        <translation>Proxy veffang má ekki vanta</translation>
    </message>
    <message>
        <source>The proxy port is incorrect</source>
        <translation>Proxy tengið er rangt</translation>
    </message>
    <message>
        <source>Proxy username can&apos;t be empty</source>
        <translation>Proxy notandanafn má ekki vanta</translation>
    </message>
    <message>
        <source>Proxy password can&apos;t be empty</source>
        <translation>Proxy lykilorð má ekki vanta</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Samræður</translation>
    </message>
    <message>
        <source>Hide main window when started</source>
        <translation>Fela aðalglugga í ræsingu</translation>
    </message>
    <message>
        <source>Notify when libraries are synchronized</source>
        <translation>Láta vita þegar söfn eru samstillt</translation>
    </message>
    <message>
        <source>Enable sync temporary files of MSOffice/Libreoffice</source>
        <translation>Virkja samstillingu tímabundinna skráa af gerð MSOffice/Libreoffice</translation>
    </message>
    <message>
        <source>Download speed limit (KB/s):</source>
        <translation>Takmörkun á hraða niðurhals (KB/s):</translation>
    </message>
    <message>
        <source>Upload speed limit (KB/s):</source>
        <translation>Takmörkun á hraða uppleðslu (KB/s):</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Einfallt</translation>
    </message>
    <message>
        <source>Do not automatically unsync a library</source>
        <translation>Ekki taka samstillingu sjálfvirkt af safni</translation>
    </message>
    <message>
        <source>Do not automatically unsync a library when its local directory is removed or unaccessible for other reasons.</source>
        <translation>Ekki taka samkeyrslu af safni þegar skráarsafn á tölvu er fjarlægt eða ekki aðgengilegt af einhverjum völdum.</translation>
    </message>
    <message>
        <source>Do not unsync a library when not found on server</source>
        <translation>Ekki taka samstillingu af safni þegar það finnst ekki á þjóni</translation>
    </message>
    <message>
        <source>Do not automatically unsync a library when it&apos;s not found on server</source>
        <translation>Ekki taka samstillingu af safni sjálfvirkt þegar það finnst ekki á þjóni</translation>
    </message>
    <message>
        <source>Enable FinderSync Extension</source>
        <translation>Virkja FinderSync viðbót</translation>
    </message>
    <message>
        <source>Enable Explorer Extension</source>
        <translation>Virkja Explorer viðbót</translation>
    </message>
    <message>
        <source>Check for updates automatically</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do not verify server certificate in HTTPS syncing</source>
        <translation>Ekki sannvotta skírteini í HTTPS samstillingu</translation>
    </message>
    <message>
        <source>Enable syncing with an existing folder with a different name</source>
        <translation>Virkja samkeyrslu við skráasafn sem er nú þegar til undir öðru nafni</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Ýtarlegt</translation>
    </message>
    <message>
        <source>Language (need restart)</source>
        <translation>Tungumál (þarfnast endurræsingar)</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Tungumál</translation>
    </message>
    <message>
        <source>Proxy Type:</source>
        <translation>Staðgengilsgerð:</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Hýsill:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Tenginúmer:</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Notendanafn:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Lykilorð:</translation>
    </message>
    <message>
        <source>Proxy server requires a password</source>
        <translation>Staðgengilsþjónn krefst lykilorðs</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Net</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Í lagi</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Hætta við</translation>
    </message>
</context>
<context>
    <name>SharedItemDelegate</name>
    <message>
        <source>Read Write</source>
        <translation>Lesa Skrifa</translation>
    </message>
    <message>
        <source>Read Only</source>
        <translation>Aðeins Lesa</translation>
    </message>
    <message>
        <source>Remove Share</source>
        <translation>Fjarlægja Deilingu</translation>
    </message>
</context>
<context>
    <name>SharedItemsTableModel</name>
    <message>
        <source>Click to edit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Created by %1</source>
        <translation>Búið til af %1</translation>
    </message>
    <message>
        <source>Read Write</source>
        <translation>Lesa Skrifa</translation>
    </message>
    <message>
        <source>Read Only</source>
        <translation>Aðeins Lesa</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>Hópur</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Notandi</translation>
    </message>
    <message>
        <source>Permission</source>
        <translation>Réttindi</translation>
    </message>
    <message>
        <source>The previous operation is still in progres</source>
        <translation>Síðasta aðgerð er enn í vinnslu</translation>
    </message>
</context>
<context>
    <name>SharedLinkDialog</name>
    <message>
        <source>Share Link</source>
        <translation>Deila Hlekk</translation>
    </message>
    <message>
        <source>Share link:</source>
        <translation>Deila hlekk:</translation>
    </message>
    <message>
        <source>Direct Download</source>
        <translation>Beint Niðurhal</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Afrita í biðminni</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Í Lagi</translation>
    </message>
</context>
<context>
    <name>ShibLoginDialog</name>
    <message>
        <source>Login with Shibboleth</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to save current account</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SslConfirmDialog</name>
    <message>
        <source>Untrusted Connection</source>
        <translation>Ótraust tenging</translation>
    </message>
    <message>
        <source>%1 uses an invalid security certificate. The connection may be insecure. Do you want to continue?</source>
        <translation>%1 notar rangt öryggisskíreini.  Tengingin er hugsanlega óörugg. Viltu halda áfram?</translation>
    </message>
    <message>
        <source>Current RSA key fingerprint is %1</source>
        <translation>Núverandi RSA fingrafar er %1</translation>
    </message>
    <message>
        <source>Previous RSA key fingerprint is %1</source>
        <translation>Fyrra RSA fingrafar var %1</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Samræða</translation>
    </message>
    <message>
        <source>Remember my choice</source>
        <translation>Mundu valið mitt</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Já</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nei</translation>
    </message>
</context>
<context>
    <name>StarredFilesListView</name>
    <message>
        <source>&amp;Open</source>
        <translation>%Opna</translation>
    </message>
    <message>
        <source>Open this file</source>
        <translation>Opnaðu þessa skrá</translation>
    </message>
    <message>
        <source>view on &amp;Web</source>
        <translation>skoða á &amp;Vef</translation>
    </message>
    <message>
        <source>view this file on website</source>
        <translation>skoða þessa skrá á vefsíðu</translation>
    </message>
</context>
<context>
    <name>StarredFilesTab</name>
    <message>
        <source>retry</source>
        <translation>reyna aftur</translation>
    </message>
    <message>
        <source>Failed to get starred files information&lt;br/&gt;Please %1</source>
        <translation>Mistókst að sækja upplýsingar um stjörnumerktar skrár&lt;br/&gt;Vinsamlegast %1</translation>
    </message>
    <message>
        <source>You have no starred files yet.</source>
        <translation>Þá hefur ekki stjörnumerkt skrár enn</translation>
    </message>
</context>
<context>
    <name>SyncErrorsDialog</name>
    <message>
        <source>File Sync Errors</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No sync errors.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SyncErrorsTableModel</name>
    <message>
        <source>Double click to open the library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Path</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Time</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UninstallHelperDialog</name>
    <message>
        <source>Uninstall %1</source>
        <translation>Fjarlægja %1</translation>
    </message>
    <message>
        <source>Do you want to remove the %1 account information?</source>
        <translation>Viltu fjarlægja reikningsupplýsingar %1?</translation>
    </message>
    <message>
        <source>Removing account information...</source>
        <translation>Fjarlægi reikningsupplýsingar...</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Svargluggi</translation>
    </message>
    <message>
        <source>text</source>
        <translation>texti</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Já</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nei</translation>
    </message>
</context>
</TS>